==> com.liferay.frontend.editor.tinymce.web-5.0.2.jar: META-INF/resources/_diffs/langs/et.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('et', {
	Cut: 'L\u00f5ika',
	'Header 2': 'Pealkiri 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Sinu veebilehitseja ei toeta otsest ligip\u00e4\u00e4su l\u00f5ikelauale. Palun kasuta selle asemel klaviatuuri kiirk\u00e4sklusi Ctrl+X/C/V.',
	Div: 'Sektsioon',
	Paste: 'Kleebi',
	Close: 'Sulge',
	'Font Family': 'Kirjastiilid',
	Pre: 'Eelvormindatud',
	'Align right': 'Joonda paremale',
	'New document': 'Uus dokument',
	Blockquote: 'Plokktsitaat',
	'Numbered list': 'J\u00e4rjestatud loend',
	'Increase indent': 'Suurenda taanet',
	Formats: 'Vormingud',
	Headers: 'P\u00e4ised',
	'Select all': 'Vali k\u00f5ik',
	'Header 3': 'Pealkiri 3',
	Blocks: 'Plokid',
	Undo: 'V\u00f5ta tagasi',
	Strikethrough: 'L\u00e4bikriipsutatud',
	'Bullet list': 'J\u00e4rjestamata loend',
	'Header 1': 'Pealkiri 1',
	Superscript: '\u00dclaindeks',
	'Clear formatting': 'Puhasta vorming',
	'Font Sizes': 'Kirja suurused',
	Subscript: 'Alaindeks',
	'Header 6': 'Pealkiri 6',
	Redo: 'Tee uuesti',
	Paragraph: 'L\u00f5ik',
	Ok: 'Ok',
	Bold: 'Rasvane',
	Code: 'Kood',
	Italic: 'Kaldkiri',
	'Align center': 'Joonda keskele',
	'Header 5': 'Pealkiri 5',
	'Decrease indent': 'V\u00e4henda taanet',
	'Header 4': 'Pealkiri 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Asetamine on n\u00fc\u00fcd tekstire\u017eiimis. Sisu asetatakse n\u00fc\u00fcd lihttekstina, kuni sa l\u00fclitad selle valiku v\u00e4lja.',
	Underline: 'Allakriipsutatud',
	Cancel: 'Katkesta',
	Justify: 'Joonda r\u00f6\u00f6pselt',
	Inline: 'Reasisene',
	Copy: 'Kopeeri',
	'Align left': 'Joonda vasakule',
	'Visual aids': 'N\u00e4itevahendid',
	'Lower Greek': 'Kreeka v\u00e4iket\u00e4hed (\u03b1, \u03b2, \u03b3)',
	Square: 'Ruut',
	Default: 'Vaikimisi',
	'Lower Alpha': 'V\u00e4iket\u00e4hed (a, b, c)',
	Circle: 'Ring',
	Disc: 'Ketas',
	'Upper Alpha': 'Suurt\u00e4hed (A, B, C)',
	'Upper Roman': 'Rooma suurt\u00e4hed (I, II, III)',
	'Lower Roman': 'Rooma v\u00e4iket\u00e4hed (i, ii, iii)',
	Name: 'Nimi',
	Anchor: 'Ankur',
	'You have unsaved changes are you sure you want to navigate away?':
		'Sul on salvestamata muudatusi. Oled Sa kindel, et soovid mujale navigeeruda?',
	'Restore last draft': 'Taasta viimane mustand',
	'Special character': 'Erim\u00e4rk',
	'Source code': 'L\u00e4htekood',
	'Right to left': 'Paremalt vasakule',
	'Left to right': 'Vasakult paremale',
	Emoticons: 'Emotikonid',
	Robots: 'Robotid',
	'Document properties': 'Dokumendi omadused',
	Title: 'Pealkiri',
	Keywords: 'M\u00e4rks\u00f5nad',
	Encoding: 'M\u00e4rgistik',
	Description: 'Kirjeldus',
	Author: 'Autor',
	Fullscreen: 'T\u00e4isekraan',
	'Horizontal line': 'Horisontaaljoon',
	'Horizontal space': 'Reavahe',
	'Insert/edit image': 'Lisa/muuda pilt',
	General: '\u00dcldine',
	Advanced: 'T\u00e4iendavad seaded',
	Source: 'Allikas',
	Border: '\u00c4\u00e4ris',
	'Constrain proportions': 'S\u00e4ilita kuvasuhe',
	'Vertical space': 'P\u00fcstine vahe',
	'Image description': 'Pildi kirjeldus',
	Style: 'Stiil',
	Dimensions: 'M\u00f5\u00f5tmed',
	'Insert image': 'Lisa pilt',
	'Insert date/time': 'Lisa kuup\u00e4ev/kellaaeg',
	'Remove link': 'Eemalda link',
	Url: 'Viide (url)',
	'Text to display': 'Kuvatav tekst',
	Anchors: 'Ankrud',
	'Insert link': 'Lisa link',
	'New window': 'Uus aken',
	None: 'Puudub',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?',
	Target: 'Sihtm\u00e4rk',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?',
	'Insert/edit link': 'Lisa/muuda link',
	'Insert/edit video': 'Lisa/muuda video',
	Poster: 'Lisaja',
	'Alternative source': 'Teine allikas',
	'Paste your embed code below:': 'Kleebi oma manustamiskood siia alla:',
	'Insert video': 'Lisa video',
	Embed: 'Manusta',
	'Nonbreaking space': 'T\u00fchim\u00e4rk (nbsp)',
	'Page break': 'Lehevahetus',
	'Paste as text': 'Aseta tekstina',
	Preview: 'Eelvaade',
	Print: 'Tr\u00fcki',
	Save: 'Salvesta',
	'Could not find the specified string.':
		'Ei suutnud leida etteantud s\u00f5net.',
	Replace: 'Asenda',
	Next: 'J\u00e4rg',
	'Whole words': 'Terviks\u00f5nad',
	'Find and replace': 'Otsi ja asenda',
	'Replace with': 'Asendus',
	Find: 'Otsi',
	'Replace all': 'Asenda k\u00f5ik',
	'Match case': 'Erista suur- ja v\u00e4iket\u00e4hti',
	Prev: 'Eelm',
	Spellcheck: '\u00d5igekirja kontroll',
	Finish: 'L\u00f5peta',
	'Ignore all': 'Eira k\u00f5iki',
	Ignore: 'Eira',
	'Insert row before': 'Lisa rida enne',
	Rows: 'Read',
	Height: 'K\u00f5rgus',
	'Paste row after': 'Kleebi rida j\u00e4rele',
	Alignment: 'Joondus',
	'Column group': 'Veergude r\u00fchm',
	Row: 'Rida',
	'Insert column before': 'Lisa tulp enne',
	'Split cell': 'T\u00fckelda lahter',
	'Cell padding': 'Lahtri sisu ja tabeli \u00e4\u00e4rise vahe',
	'Cell spacing': 'Lahtrivahe',
	'Row type': 'Rea t\u00fc\u00fcp',
	'Insert table': 'Lisa tabel',
	Body: 'P\u00f5hiosa',
	Caption: 'Alapealkiri',
	Footer: 'Jalus',
	'Delete row': 'Kustuta rida',
	'Paste row before': 'Kleebi rida enne',
	Scope: 'Ulatus',
	'Delete table': 'Kustuta tabel',
	'Header cell': 'P\u00e4islahter',
	Column: 'Tulp',
	Cell: 'Lahter',
	Header: 'P\u00e4is',
	'Cell type': 'Lahtri t\u00fc\u00fcp',
	'Copy row': 'Kopeeri rida',
	'Row properties': 'Rea omadused',
	'Table properties': 'Tabeli omadused',
	'Row group': 'Ridade r\u00fchm',
	Right: 'Paremal',
	'Insert column after': 'Lisa tulp j\u00e4rele',
	Cols: 'Veerud',
	'Insert row after': 'Lisa rida j\u00e4rele',
	Width: 'Laius',
	'Cell properties': 'Lahtri omadused',
	Left: 'Vasakul',
	'Cut row': 'L\u00f5ika rida',
	'Delete column': 'Kustuta tulp',
	Center: 'Keskel',
	'Merge cells': '\u00dchenda lahtrid',
	'Insert template': 'Lisa mall',
	Templates: 'Mallid',
	'Background color': 'Tausta v\u00e4rv',
	'Text color': 'Teksti v\u00e4rv',
	'Show blocks': 'N\u00e4ita plokke',
	'Show invisible characters': 'N\u00e4ita peidetud m\u00e4rke',
	'Words: {0}': 'S\u00f5nu: {0}',
	Insert: 'Sisesta',
	File: 'Fail',
	Edit: 'Muuda',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rikastatud teksti ala. Men\u00fc\u00fc jaoks vajuta ALT-F9. T\u00f6\u00f6riistariba jaoks vajuta ALT-F10. Abi saamiseks vajuta ALT-0.',
	Tools: 'T\u00f6\u00f6riistad',
	View: 'Vaade',
	Table: 'Tabel',
	Format: 'Vorming',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/et.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('et', {
	'Cut': 'L\u00f5ika',
	'Header 2': 'Pealkiri 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Sinu veebilehitseja ei toeta otsest ligip\u00e4\u00e4su l\u00f5ikelauale. Palun kasuta selle asemel klaviatuuri kiirk\u00e4sklusi Ctrl+X/C/V.',
	'Div': 'Sektsioon',
	'Paste': 'Kleebi',
	'Close': 'Sulge',
	'Font Family': 'Kirjastiilid',
	'Pre': 'Eelvormindatud',
	'Align right': 'Joonda paremale',
	'New document': 'Uus dokument',
	'Blockquote': 'Plokktsitaat',
	'Numbered list': 'J\u00e4rjestatud loend',
	'Increase indent': 'Suurenda taanet',
	'Formats': 'Vormingud',
	'Headers': 'P\u00e4ised',
	'Select all': 'Vali k\u00f5ik',
	'Header 3': 'Pealkiri 3',
	'Blocks': 'Plokid',
	'Undo': 'V\u00f5ta tagasi',
	'Strikethrough': 'L\u00e4bikriipsutatud',
	'Bullet list': 'J\u00e4rjestamata loend',
	'Header 1': 'Pealkiri 1',
	'Superscript': '\u00dclaindeks',
	'Clear formatting': 'Puhasta vorming',
	'Font Sizes': 'Kirja suurused',
	'Subscript': 'Alaindeks',
	'Header 6': 'Pealkiri 6',
	'Redo': 'Tee uuesti',
	'Paragraph': 'L\u00f5ik',
	'Ok': 'Ok',
	'Bold': 'Rasvane',
	'Code': 'Kood',
	'Italic': 'Kaldkiri',
	'Align center': 'Joonda keskele',
	'Header 5': 'Pealkiri 5',
	'Decrease indent': 'V\u00e4henda taanet',
	'Header 4': 'Pealkiri 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Asetamine on n\u00fc\u00fcd tekstire\u017eiimis. Sisu asetatakse n\u00fc\u00fcd lihttekstina, kuni sa l\u00fclitad selle valiku v\u00e4lja.',
	'Underline': 'Allakriipsutatud',
	'Cancel': 'Katkesta',
	'Justify': 'Joonda r\u00f6\u00f6pselt',
	'Inline': 'Reasisene',
	'Copy': 'Kopeeri',
	'Align left': 'Joonda vasakule',
	'Visual aids': 'N\u00e4itevahendid',
	'Lower Greek': 'Kreeka v\u00e4iket\u00e4hed (\u03b1, \u03b2, \u03b3)',
	'Square': 'Ruut',
	'Default': 'Vaikimisi',
	'Lower Alpha': 'V\u00e4iket\u00e4hed (a, b, c)',
	'Circle': 'Ring',
	'Disc': 'Ketas',
	'Upper Alpha': 'Suurt\u00e4hed (A, B, C)',
	'Upper Roman': 'Rooma suurt\u00e4hed (I, II, III)',
	'Lower Roman': 'Rooma v\u00e4iket\u00e4hed (i, ii, iii)',
	'Name': 'Nimi',
	'Anchor': 'Ankur',
	'You have unsaved changes are you sure you want to navigate away?':
		'Sul on salvestamata muudatusi. Oled Sa kindel, et soovid mujale navigeeruda?',
	'Restore last draft': 'Taasta viimane mustand',
	'Special character': 'Erim\u00e4rk',
	'Source code': 'L\u00e4htekood',
	'Right to left': 'Paremalt vasakule',
	'Left to right': 'Vasakult paremale',
	'Emoticons': 'Emotikonid',
	'Robots': 'Robotid',
	'Document properties': 'Dokumendi omadused',
	'Title': 'Pealkiri',
	'Keywords': 'M\u00e4rks\u00f5nad',
	'Encoding': 'M\u00e4rgistik',
	'Description': 'Kirjeldus',
	'Author': 'Autor',
	'Fullscreen': 'T\u00e4isekraan',
	'Horizontal line': 'Horisontaaljoon',
	'Horizontal space': 'Reavahe',
	'Insert/edit image': 'Lisa/muuda pilt',
	'General': '\u00dcldine',
	'Advanced': 'T\u00e4iendavad seaded',
	'Source': 'Allikas',
	'Border': '\u00c4\u00e4ris',
	'Constrain proportions': 'S\u00e4ilita kuvasuhe',
	'Vertical space': 'P\u00fcstine vahe',
	'Image description': 'Pildi kirjeldus',
	'Style': 'Stiil',
	'Dimensions': 'M\u00f5\u00f5tmed',
	'Insert image': 'Lisa pilt',
	'Insert date/time': 'Lisa kuup\u00e4ev/kellaaeg',
	'Remove link': 'Eemalda link',
	'Url': 'Viide (url)',
	'Text to display': 'Kuvatav tekst',
	'Anchors': 'Ankrud',
	'Insert link': 'Lisa link',
	'New window': 'Uus aken',
	'None': 'Puudub',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?',
	'Target': 'Sihtm\u00e4rk',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?',
	'Insert/edit link': 'Lisa/muuda link',
	'Insert/edit video': 'Lisa/muuda video',
	'Poster': 'Lisaja',
	'Alternative source': 'Teine allikas',
	'Paste your embed code below:': 'Kleebi oma manustamiskood siia alla:',
	'Insert video': 'Lisa video',
	'Embed': 'Manusta',
	'Nonbreaking space': 'T\u00fchim\u00e4rk (nbsp)',
	'Page break': 'Lehevahetus',
	'Paste as text': 'Aseta tekstina',
	'Preview': 'Eelvaade',
	'Print': 'Tr\u00fcki',
	'Save': 'Salvesta',
	'Could not find the specified string.':
		'Ei suutnud leida etteantud s\u00f5net.',
	'Replace': 'Asenda',
	'Next': 'J\u00e4rg',
	'Whole words': 'Terviks\u00f5nad',
	'Find and replace': 'Otsi ja asenda',
	'Replace with': 'Asendus',
	'Find': 'Otsi',
	'Replace all': 'Asenda k\u00f5ik',
	'Match case': 'Erista suur- ja v\u00e4iket\u00e4hti',
	'Prev': 'Eelm',
	'Spellcheck': '\u00d5igekirja kontroll',
	'Finish': 'L\u00f5peta',
	'Ignore all': 'Eira k\u00f5iki',
	'Ignore': 'Eira',
	'Insert row before': 'Lisa rida enne',
	'Rows': 'Read',
	'Height': 'K\u00f5rgus',
	'Paste row after': 'Kleebi rida j\u00e4rele',
	'Alignment': 'Joondus',
	'Column group': 'Veergude r\u00fchm',
	'Row': 'Rida',
	'Insert column before': 'Lisa tulp enne',
	'Split cell': 'T\u00fckelda lahter',
	'Cell padding': 'Lahtri sisu ja tabeli \u00e4\u00e4rise vahe',
	'Cell spacing': 'Lahtrivahe',
	'Row type': 'Rea t\u00fc\u00fcp',
	'Insert table': 'Lisa tabel',
	'Body': 'P\u00f5hiosa',
	'Caption': 'Alapealkiri',
	'Footer': 'Jalus',
	'Delete row': 'Kustuta rida',
	'Paste row before': 'Kleebi rida enne',
	'Scope': 'Ulatus',
	'Delete table': 'Kustuta tabel',
	'Header cell': 'P\u00e4islahter',
	'Column': 'Tulp',
	'Cell': 'Lahter',
	'Header': 'P\u00e4is',
	'Cell type': 'Lahtri t\u00fc\u00fcp',
	'Copy row': 'Kopeeri rida',
	'Row properties': 'Rea omadused',
	'Table properties': 'Tabeli omadused',
	'Row group': 'Ridade r\u00fchm',
	'Right': 'Paremal',
	'Insert column after': 'Lisa tulp j\u00e4rele',
	'Cols': 'Veerud',
	'Insert row after': 'Lisa rida j\u00e4rele',
	'Width': 'Laius',
	'Cell properties': 'Lahtri omadused',
	'Left': 'Vasakul',
	'Cut row': 'L\u00f5ika rida',
	'Delete column': 'Kustuta tulp',
	'Center': 'Keskel',
	'Merge cells': '\u00dchenda lahtrid',
	'Insert template': 'Lisa mall',
	'Templates': 'Mallid',
	'Background color': 'Tausta v\u00e4rv',
	'Text color': 'Teksti v\u00e4rv',
	'Show blocks': 'N\u00e4ita plokke',
	'Show invisible characters': 'N\u00e4ita peidetud m\u00e4rke',
	'Words: {0}': 'S\u00f5nu: {0}',
	'Insert': 'Sisesta',
	'File': 'Fail',
	'Edit': 'Muuda',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Rikastatud teksti ala. Men\u00fc\u00fc jaoks vajuta ALT-F9. T\u00f6\u00f6riistariba jaoks vajuta ALT-F10. Abi saamiseks vajuta ALT-0.',
	'Tools': 'T\u00f6\u00f6riistad',
	'View': 'Vaade',
	'Table': 'Tabel',
	'Format': 'Vorming',
});
